@@ -1073,8 +1073,28 @@ main(int argc, char **argv)
         error_get_gl_symbol("glGetIntegerv");
 
     glGetString = waffle_dl_sym(opts.dl, "glGetString");
-    if (!glGetString)
+    if (!glGetString) {
         error_get_gl_symbol("glGetString");
+    }
+
+    const struct wflinfo_config_attrs config_attrs = {
+        .api = opts.context_api,
+        .profile = opts.context_profile,
+        .major = opts.context_major,
+        .minor = opts.context_minor,
+        .forward_compat = opts.context_forward_compatible,
+        .debug = opts.context_debug,
+    };
+
+    wflinfo_create_context(dpy, config_attrs, &ctx, &config);
+
+    window = waffle_window_create(config, WINDOW_WIDTH, WINDOW_HEIGHT);
+    if (!window)
+        error_waffle();
+
+    ok = waffle_make_current(dpy, window, ctx);
+    if (!ok)
+        error_waffle();
 
     // Retrieving GL functions is tricky. When glGetStringi is supported, here
     // are some boggling variations as of 2014-11-19:
@@ -1099,27 +1119,6 @@ main(int argc, char **argv)
         glGetStringi = waffle_get_proc_address("glGetStringi");
     }
 
-    const struct wflinfo_config_attrs config_attrs = {
-        .api = opts.context_api,
-        .profile = opts.context_profile,
-        .major = opts.context_major,
-        .minor = opts.context_minor,
-        .forward_compat = opts.context_forward_compatible,
-        .debug = opts.context_debug,
-    };
-
-    wflinfo_create_context(dpy, config_attrs, &ctx, &config);
-
-    window = waffle_window_create(config, WINDOW_WIDTH, WINDOW_HEIGHT);
-    if (!window)
-        error_waffle();
-
-    ok = waffle_make_current(dpy, window, ctx);
-    if (!ok)
-        error_waffle();
-
-    glGetStringi = waffle_get_proc_address("glGetStringi");
-
     ok = print_wflinfo(&opts);
     if (!ok)
         error_waffle();
